Пример документации

На этой странице

- Списки
  - Ненумерованные списки
  - Нумерованные списки
- Инфоблоки
- Таблицы
- Вкладки и код
- Изображения
- Сниппеты и плитки
  - Сниппеты
  - Плитки

# Форматирование

Lorem ipsum dolor sit amet, consectetur adipiscing elit, sed do eiusmod tempor incididunt ut labore et dolore magna aliqua. Proin tortor purus platea sit eu id nisi litora libero. Neque vulputate consequat ac amet augue blandit maximus aliquet congue. Pharetra vestibulum posuere ornare faucibus fusce dictumst orci aenean eu facilisis ut volutpat commodo senectus purus himenaeos fames primis convallis nisi.

Phasellus fermentum malesuada phasellus netus dictum aenean placerat egestas amet. Ornare taciti semper dolor tristique morbi. Sem leo tincidunt aliquet semper eu `lectus scelerisque quis`. Sagittis vivamus mollis nisi mollis enim fermentum laoreet.

Curabitur semper venenatis lectus viverra ex dictumst nulla maximus. Primis iaculis elementum conubia feugiat venenatis dolor augue ac blandit nullam ac phasellus `turpis feugiat mollis`. Duis lectus porta mattis imperdiet vivamus augue litora lectus arcu. Justo torquent pharetra volutpat ad blandit bibendum accumsan nec elit cras luctus primis ipsum gravida class congue.

> Vehicula etiam elementum finibus enim duis feugiat commodo adipiscing tortor tempor elit. Et mollis consectetur habitant turpis tortor consectetur adipiscing vulputate dolor lectus iaculis convallis adipiscing. Nam hendrerit dignissim condimentum ullamcorper diam morbi eget consectetur odio in sagittis.

Rutrum dictumst mollis vestibulum est nascetur neque nullam, cursus placerat pellentesque tellus mi tortor. Commodo augue iaculis rhoncus integer massa imperdiet porta enim sed donec platea, praesent himenaeos turpis nisi sem class lacinia suspendisse justo congue. Condimentum dignissim nostra aptent felis ultrices accumsan rutrum, aenean placerat enim habitasse ridiculus faucibus inceptos nullam, gravida augue phasellus in litora at.

## Списки#

### Ненумерованные списки#

Компактный список:

- Lorem ipsum dolor sit amet,
- consectetur adipiscing elit,
- sed do eiusmod tempor incididunt.

Некомпактный список:

- Lorem ipsum dolor sit amet, consectetur adipiscing elit, sed do eiusmod tempor incididunt ut labore et dolore magna aliqua. Proin tortor purus platea sit eu id nisi litora libero. Neque vulputate consequat ac amet augue blandit maximus aliquet congue. Pharetra vestibulum posuere ornare faucibus fusce dictumst orci aenean eu facilisis ut volutpat commodo senectus purus himenaeos fames primis convallis nisi.

- Phasellus fermentum malesuada phasellus netus dictum aenean placerat egestas amet. Ornare taciti semper dolor tristique morbi. Sem leo tincidunt aliquet semper eu lectus scelerisque quis. Sagittis vivamus mollis nisi mollis enim fermentum laoreet.

  - Lorem ipsum dolor sit amet, consectetur adipiscing elit, sed do eiusmod tempor incididunt ut labore et dolore magna aliqua. Proin tortor purus platea sit eu id nisi litora libero. Neque vulputate consequat ac amet augue blandit maximus aliquet congue. Pharetra vestibulum posuere ornare faucibus fusce dictumst orci aenean eu facilisis ut volutpat commodo senectus purus himenaeos fames primis convallis nisi.

  - Phasellus fermentum malesuada phasellus netus dictum aenean placerat egestas amet. Ornare taciti semper dolor tristique morbi. Sem leo tincidunt aliquet semper eu lectus scelerisque quis. Sagittis vivamus mollis nisi mollis enim fermentum laoreet.

    - Lorem ipsum dolor sit amet,
    - consectetur adipiscing elit,
    - sed do eiusmod tempor incididunt.

- Curabitur semper venenatis lectus viverra ex dictumst nulla maximus. Primis iaculis elementum conubia feugiat venenatis dolor augue ac blandit nullam ac phasellus turpis feugiat mollis. Duis lectus porta mattis imperdiet vivamus augue litora lectus arcu. Justo torquent pharetra volutpat ad blandit bibendum accumsan nec elit cras luctus primis ipsum gravida class congue.

### Нумерованные списки#

Номера пунктов никуда не залезут, потому что они родные браузерные, я поменял только цвет.

1. Lorem ipsum dolor sit amet,
2. consectetur adipiscing elit,
3. sed do eiusmod tempor incididunt ut labore et dolore magna aliqua.
4. Proin tortor purus platea sit eu id nisi litora libero.
5. Neque vulputate consequat ac amet augue blandit maximus aliquet congue.
6. Pharetra vestibulum posuere ornare faucibus fusce dictumst
7. orci aenean eu facilisis ut volutpat commodo
8. senectus purus himenaeos fames primis convallis nisi.
9. Phasellus fermentum malesuada phasellus netus dictum aenean placerat egestas amet.
10. Ornare taciti semper dolor tristique morbi.
11. Sem leo tincidunt aliquet semper eu lectus scelerisque quis.
12. Sagittis vivamus mollis nisi mollis enim fermentum laoreet.

Вложенная нумерация выглядит так:

13. Lorem ipsum dolor sit amet,
14. consectetur adipiscing elit,
15. sed do eiusmod tempor incididunt ut labore et dolore magna aliqua.
    1. Proin tortor purus platea sit eu id nisi litora libero.
    2. Neque vulputate consequat ac amet augue blandit maximus aliquet congue.
    3. Pharetra vestibulum posuere ornare faucibus fusce dictumst
       1. orci aenean eu facilisis ut volutpat commodo
       2. senectus purus himenaeos fames primis convallis nisi.
       3. Phasellus fermentum malesuada phasellus netus dictum aenean placerat egestas amet.
    4. Ornare taciti semper dolor tristique morbi.
    5. Sem leo tincidunt aliquet semper eu lectus scelerisque quis.

При необходимости также включим поддержку такого формата:

1. Lorem ipsum dolor sit amet,
2. consectetur adipiscing elit,
3. sed do eiusmod tempor incididunt ut labore et dolore magna aliqua.

Или такого:

1. Lorem ipsum dolor sit amet,
2. consectetur adipiscing elit,
3. sed do eiusmod tempor incididunt ut labore et dolore magna aliqua.

## Инфоблоки#

Примечание. Lorem ipsum dolor sit amet, consectetur adipiscing elit, sed do eiusmod tempor incididunt ut labore et dolore magna aliqua. Proin tortor purus platea sit eu id nisi litora libero. Neque vulputate consequat ac amet augue blandit maximus aliquet congue. Pharetra vestibulum posuere ornare faucibus fusce dictumst orci aenean eu facilisis ut volutpat commodo senectus purus himenaeos fames primis convallis nisi.

Phasellus fermentum malesuada phasellus netus dictum aenean placerat egestas amet. Ornare taciti semper dolor tristique morbi. Sem leo tincidunt aliquet semper eu lectus scelerisque quis. Sagittis vivamus mollis nisi mollis enim fermentum laoreet.

Пример. Curabitur semper venenatis lectus viverra ex dictumst nulla maximus. Primis iaculis elementum conubia feugiat venenatis dolor augue ac blandit nullam ac phasellus turpis feugiat mollis. Duis lectus porta mattis imperdiet vivamus augue litora lectus arcu. Justo torquent pharetra volutpat ad blandit bibendum accumsan nec elit cras luctus primis ipsum gravida class congue.

Внимание. Vehicula etiam elementum finibus enim duis feugiat commodo adipiscing tortor tempor elit. Et mollis consectetur habitant turpis tortor consectetur adipiscing vulputate dolor lectus iaculis convallis adipiscing. Nam hendrerit dignissim condimentum ullamcorper diam morbi eget consectetur odio in sagittis.

Важно. Rutrum dictumst mollis vestibulum est nascetur neque nullam, cursus placerat pellentesque tellus mi tortor. Commodo augue iaculis rhoncus integer massa imperdiet porta enim sed donec platea, praesent himenaeos turpis nisi sem class lacinia suspendisse justo congue. Condimentum dignissim nostra aptent felis ultrices accumsan rutrum, aenean placerat enim habitasse ridiculus faucibus inceptos nullam, gravida augue phasellus in litora at.

## Таблицы#

№ | Параметр | Значение | Комментарий
--- | --- | --- | ---
1 | Операционная система | Windows | Поддерживаются версии 10 и 11.
Linux | Рекомендуются Ubuntu и CentOS последних версий. Другие дистрибутивы не поддерживаются.
2 | Браузер | Chrome | Рекомендуется последняя версия.
Firefox | Рекомендуется последняя версия.

## Вкладки и `код`#

Это код во вкладках:

Python

    class MyWebProcessor(WebProcessor):
        async def process_header(self, header: Header, page: Page):
            header, = await super().process_header(header, page)
            if header.level >= 2:
                url = '#' + header.identifier
                header.content += Space(), Link(Str('#'), url=url)
            return header,

Bash

    echo 'Hello, world!'

Другие языки

Lorem ipsum dolor sit amet, consectetur adipiscing elit, sed do eiusmod tempor incididunt ut labore et dolore magna aliqua. Proin tortor purus platea sit eu id nisi litora libero. Neque vulputate consequat ac amet augue blandit maximus aliquet congue. Pharetra vestibulum posuere ornare faucibus fusce dictumst orci aenean eu facilisis ut volutpat commodo senectus purus himenaeos fames primis convallis nisi.

Phasellus fermentum malesuada phasellus netus dictum aenean placerat egestas amet. Ornare taciti semper dolor tristique morbi. Sem leo tincidunt aliquet semper eu lectus scelerisque quis. Sagittis vivamus mollis nisi mollis enim fermentum laoreet.

    print('Hello, world!')

А это просто код:

    class MyWebProcessor(WebProcessor):
        async def process_header(self, header: Header, page: Page):
            header, = await super().process_header(header, page)
            if header.level >= 2:
                url = '#' + header.identifier
                header.content += Space(), Link(Str('#'), url=url)
            return header,

А это просто следующий абзац.

## Изображения#

Вот простое изображение без подписи:

Вот изображение с подписью:

Рисунок 1. Очень важный рисунок.

Вот непрогрузившийся рисунок с alt-текстом:

Внутри абзаца могут быть инлайновые картинки, такие как эта . Если картинка не прогружается, то alt-текст остаётся читабельным: .

## Сниппеты и плитки#

### Сниппеты#

Другая статья
Другая статья

Эта ссылка ведёт на какую-то другую статью.

Другая статья

Эта ссылка ведёт на какую-то другую статью. У неё очень большое описание, которое может занимать несколько строк или даже пару абзацев.

Такое описание всё равно должно выглядеть нормально и не ломаться.

### Плитки#

Другая статья

Эта ссылка ведёт на какую-то другую статью.

Другая статья

Эта ссылка ведёт на какую-то другую статью.

Другая статья

Эта ссылка ведёт на какую-то другую статью.

Другая статья

Эта ссылка ведёт на какую-то другую статью. У неё очень большое описание, которое может занимать несколько строк или даже пару абзацев.

Такое описание всё равно должно выглядеть нормально и не ломаться.

Другая статья

Эта ссылка ведёт на какую-то другую статью.

Другая статья

Эта ссылка ведёт на какую-то другую статью.